**Example 1: 查询Datahub主题列表**



Input: 

```
tccli ckafka DescribeDatahubTopics --cli-unfold-argument ```

Output: 
```
{
    "Response": {
        "Result": {
            "TotalCount": 1,
            "TopicList": [
                {}
            ]
        },
        "RequestId": "fd9afa97-cc0f-4ea7-9da8-63914a0877e1"
    }
}
```

